Changelog
=========

1.0.1 (1/14/2026)
-----
  * remove requirements*.txt, all deps in pyproject.toml
  * update readthedocs configuration
  * update docs/conf.py
  * update github actions
  * improve update_citation.py
  * move jupyter_lite_config.json to ofiber folder

1.0.0
-----
  * Jupyterlite support
  * improve citation
  * add make lab target
  * add make readme target for images
  * simplify ronchi-dynamic and foucault-dynamic
  * fix README so code is correct
  * bump minimum python to 3.9 
  * fix zenodo links in README
  * use venv for packaging and testing
  * remove setup.py and setup.sh
  * no longer package test files
  * clean up MANIFEST.IN
  * improve pyproject.toml
  * requirements-dev.txt is now complete

0.9.0
-----
  * restructure module
  * add citation
  * add conda support
  * add github test action
  * add github pypi action
  * add github citation action
  * add copyright stuff
  * add ruff support
  * overall linting of files
  * use build.os for .readthedocs
  * add more badges, tweak colors

v0.5.1
------
  * create pure python packaging
  * include wheel file
  * package as python3 only
  * fix flake8 warnings
  * add pypi badge
  * add new targets
  * automate notebook checking

v0.5.0
------
  * initial check-in
  * basic functionality for Ronchi tests
  * basic functionality for Foucault knife edge tests
